# -*- coding: utf-8 -*-
"""
@Author: ChenXiaolei
@Date: 2020-05-21 10:31:14
@LastEditTime: 2020-05-21 10:36:41
@LastEditors: ChenXiaolei
@Description: 控制台主文件
"""

from seven_framework.console.base_console import *


def main():
    pass


if __name__ == "__main__":
    logger_info.info("application begin")
    main()




#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class TaskCountModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(TaskCountModel, self).__init__(TaskCount, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class TaskCount:

    def __init__(self):
        super(TaskCount, self).__init__()
        self.id = 0  # 标识由 md5_encrypt_int(actid+areaid+tasktype+tasksubtype+userid)生成
        self.app_id = ""  # 应用标识
        self.act_id = 0  # 活动标识
        self.module_id = 0  # 活动模块标识
        self.user_id = 0  # 用户标识
        self.open_id = ""  # open_id
        self.task_type = 0  # 任务类型（枚举TaskType）
        self.task_sub_type = ""  # 任务子类型(用于指定任务里的再细分，比如:指定金额任务分不同档位金额)
        self.complete_count = 0  # 任务完成数
        self.now_count = 0  # 当前计数
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.modify_date = "1900-01-01 00:00:00"  # 更新时间
        self.modify_day = 0  # 更新天(19000101)
        self.remark = ""  # 备注

    @classmethod
    def get_field_list(self):
        return ['id', 'app_id', 'act_id', 'module_id', 'user_id', 'open_id', 'task_type', 'task_sub_type', 'complete_count', 'now_count', 'create_date', 'modify_date', 'modify_day', 'remark']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "task_count_tb"
    


# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2021-07-19 13:37:16
@LastEditTime: 2021-08-06 12:37:43
@LastEditors: HuangJianYi
@Description: 
"""
import threading, multiprocessing
from seven_framework.console.base_console import *
from seven_cloudapp_frame.libs.customize.seven_helper import *
from seven_cloudapp_frame.models.db_models import stat

from seven_cloudapp_frame.models.db_models.asset.asset_inventory_model import *
from seven_cloudapp_frame.models.db_models.asset.asset_warn_notice_model import *
from seven_cloudapp_frame.models.db_models.asset.asset_log_model import *
from seven_cloudapp_frame.models.db_models.stat.stat_queue_model import *
from seven_cloudapp_frame.models.db_models.stat.stat_orm_model import *
from seven_cloudapp_frame.models.db_models.stat.stat_report_model import *
from seven_cloudapp_frame.models.db_models.stat.stat_log_model import *


class FrameConsoleModel():
    """
    :description: 控制台基类
    """
    def console_asset_warn(self, mod_count=10, sub_table_count=0):
        """
        :description: 控制台资产预警
        :param mod_count: 单表队列数
        :param sub_table_count: 分表数
        :return: 
        :last_editors: HuangJianYi
        """
        if sub_table_count == 0:

            self._start_process_user_asset_warn(None, mod_count)
            self._start_process_asset_inventory_warn(None, mod_count)

        else:

            for i in range(sub_table_count):

                t = multiprocessing.Process(target=self._start_process_user_asset_warn, args=[str(i), mod_count])
                t.start()

                j = multiprocessing.Process(target=self._start_process_asset_inventory_warn, args=[str(i), mod_count])
                j.start()
        
        l = threading.Thread(target=self._process_onlyid_warn, args=[])
        l.start()

    def console_stat_queue(self, mod_count=10, sub_table_count=0):
        """
        :description: 控制台统计上报
        :param mod_count: 单表队列数
        :param sub_table_count: 分表数
        :return: 
        :last_editors: HuangJianYi
        """
        if sub_table_count == 0:

            self._start_process_stat_queue(None, mod_count)

        else:

            for i in range(sub_table_count):

                t = multiprocessing.Process(target=self._start_process_stat_queue, args=[str(i), mod_count])
                t.start()

    def _start_process_user_asset_warn(self, sub_table, mod_count):

        for i in range(mod_count):

            t = threading.Thread(target=self._process_user_asset_warn, args=[sub_table, i, mod_count])
            t.start()

    def _start_process_asset_inventory_warn(self, sub_table, mod_count):

        for i in range(mod_count):

            j = threading.Thread(target=self._process_asset_inventory_warn, args=[sub_table, i, mod_count])
            j.start()

    def _process_user_asset_warn(self, sub_table, mod_value, mod_count):
        """
        :description: 处理用户资产负数预警
        :param sub_table: 分表名称
        :param mod_value: 当前队列值
        :param mod_count: 队列数
        :return: 
        :last_editors: HuangJianYi
        """
        asset_log_model = AssetLogModel(sub_table=sub_table)
        asset_warn_notice_model = AssetWarnNoticeModel()
        print(f"{TimeHelper.get_now_format_time()} 用户资产负数预警队列{mod_value}启动")
        while True:
            try:
                now_date = TimeHelper.get_now_format_time()
                now_day_int = SevenHelper.get_now_day_int()
                asset_log_list = asset_log_model.get_list(f"MOD(user_id,{mod_count})={mod_value} and now_value<0 and {now_day_int}>warn_day ", order_by="create_date asc", limit="100")
                if len(asset_log_list) > 0:
                    for asset_log in asset_log_list:
                        try:
                            asset_log.warn_date = now_date
                            asset_log.warn_day = now_day_int
                            asset_log_model.update_entity(asset_log, "warn_date,warn_day")

                            asset_warn_notice = AssetWarnNotice()
                            asset_warn_notice.app_id = asset_log.app_id
                            asset_warn_notice.act_id = asset_log.act_id
                            asset_warn_notice.handler_name = asset_log.handler_name
                            asset_warn_notice.request_id = asset_log.request_id
                            asset_warn_notice.user_id = asset_log.user_id
                            asset_warn_notice.open_id = asset_log.open_id
                            asset_warn_notice.user_nick = asset_log.user_nick
                            asset_warn_notice.asset_type = asset_log.asset_type
                            asset_warn_notice.asset_object_id = asset_log.asset_object_id
                            if asset_log.asset_type == 1:
                                asset_warn_notice.log_title = "次数异常"
                                asset_warn_notice.info_desc = f"值为负数:{asset_log.now_value}"
                            elif asset_log.asset_type == 2:
                                asset_warn_notice.log_title = "积分异常"
                                asset_warn_notice.info_desc = f"值为负数:{asset_log.now_value}"
                            else:
                                asset_warn_notice.log_title = f"价格档位异常"
                                asset_warn_notice.info_desc = f"档位ID:{asset_log.asset_object_id},值为负数:{asset_log.now_value}"

                            asset_warn_notice.info_json = SevenHelper.json_dumps(asset_log)
                            asset_warn_notice.create_date = now_date
                            asset_warn_notice.create_day = now_day_int
                            asset_warn_notice_model.add_entity(asset_warn_notice)

                        except Exception as ex:
                            logger_error.error(f"用户资产负数预警队列{mod_value}异常,json串:{SevenHelper.json_dumps(asset_log)},ex:{ex.decode()}")
                            continue
                else:
                    time.sleep(10)
            except Exception as ex:
                time.sleep(10)
         
    def _process_onlyid_warn(self):
        """
        :description: 处理唯一值并发预警
        :return: 
        :last_editors: HuangJianYi
        """
        asset_warn_notice_model = AssetWarnNoticeModel()
        redis_init = SevenHelper.redis_init()
        while True:
            try:
                hash_name_1 = f"warn_handler_list_{str(SevenHelper.get_now_int(fmt='%Y%m%d'))}"
                hkeys = redis_init.hkeys(hash_name_1)
                if len(hkeys)<=0:
                    time.sleep(10)
                    continue
                for key in hkeys:
                    date_start = TimeHelper.format_time_to_datetime(format='%Y-%m-%d %H:%M')
                    date_end = date_start + datetime.timedelta(minutes=5)
                    date_list = []
                    while date_start < date_end:
                        date_list.append(str(TimeHelper.datetime_to_format_time(date_start, '%Y%m%d%H%M')))
                        date_start += datetime.timedelta(minutes=1)
                    hash_name_2 = f"{hash_name_1}:{key}"
                    value_list = redis_init.hmget(hash_name_2,date_list)
                    if not value_list or len(value_list)<=0:
                        continue
                    count = 0
                    for value in value_list:
                        count += int(value)
                    if count <= 0:
                        continue
                    hash_value_1 = redis_init.hget(hash_name_1,key)
                    hash_value_1 = SevenHelper.json_loads(hash_value_1) if hash_value_1 else {"app_id":"","handler_name":""}
                    asset_warn_notice = AssetWarnNotice()
                    asset_warn_notice.app_id = hash_value_1["app_id"]
                    asset_warn_notice.act_id = 0
                    asset_warn_notice.handler_name = hash_value_1["handler_name"]
                    asset_warn_notice.request_id =""
                    asset_warn_notice.user_id = ""
                    asset_warn_notice.open_id = ""
                    asset_warn_notice.user_nick = ""
                    asset_warn_notice.asset_type = 0
                    asset_warn_notice.asset_object_id = ""
                    asset_warn_notice.log_title = "并发拦截"
                    asset_warn_notice.info_desc = f"{date_start}-{date_end}进行了{count}次拦截"
                    asset_warn_notice.info_json = {}
                    asset_warn_notice.create_date = SevenHelper.get_now_datetime()
                    asset_warn_notice.create_day = SevenHelper.get_now_day_int()
                    asset_warn_notice_model.add_entity(asset_warn_notice)
                time.sleep(5*60)    
            except Exception as ex:
                time.sleep(10)
                
    def _process_asset_inventory_warn(self, sub_table, mod_value, mod_count):
        """
        :description: 处理资产每日进销存是否对等预警
        :param sub_table: 分表名称
        :param mod_value: 当前队列值
        :param mod_count: 队列数
        :return: 
        :last_editors: HuangJianYi
        """
        asset_inventory_model = AssetInventoryModel(sub_table=sub_table)
        asset_warn_notice_model = AssetWarnNoticeModel()
        print(f"{TimeHelper.get_now_format_time()} 资产每日进销存预警队列{mod_value}启动")
        while True:
            try:
                now_date = TimeHelper.get_now_format_time()
                now_day_int = SevenHelper.get_now_day_int()
                asset_inventory_list = asset_inventory_model.get_list(f"MOD(user_id,{mod_count})={mod_value} and create_day={now_day_int} and process_count=0", order_by="create_date asc", limit="100")
                if len(asset_inventory_list) > 0:
                    for asset_inventory in asset_inventory_list:
                        try:
                            asset_inventory.process_count = 1
                            asset_inventory.process_date = now_date
                            asset_inventory_model.update_entity(asset_inventory, "process_count,process_date")

                            if (asset_inventory.history_value + asset_inventory.inc_value + asset_inventory.dec_value) != asset_inventory.now_value:

                                asset_warn_notice = AssetWarnNotice()
                                asset_warn_notice.app_id = asset_inventory.app_id
                                asset_warn_notice.act_id = asset_inventory.act_id
                                asset_warn_notice.handler_name = ""
                                asset_warn_notice.request_id = ""
                                asset_warn_notice.user_id = asset_inventory.user_id
                                asset_warn_notice.open_id = asset_inventory.open_id
                                asset_warn_notice.user_nick = asset_inventory.user_nick
                                asset_warn_notice.asset_type = asset_inventory.asset_type
                                asset_warn_notice.asset_object_id = asset_inventory.asset_object_id
                                asset_warn_notice.info_desc = f"历史值:{asset_inventory.history_value},增加：{asset_inventory.inc_value},减少：{asset_inventory.dec_value},当前值:{asset_inventory.now_value}"
                                if asset_inventory.asset_type == 1:
                                    asset_warn_notice.log_title = "次数进销存异常"
                                elif asset_inventory.asset_type == 2:
                                    asset_warn_notice.log_title = "积分进销存异常"
                                else:
                                    asset_warn_notice.log_title = "价格档位进销存异常"
                                    asset_warn_notice.info_desc = f"档位ID:{asset_inventory.asset_object_id}," + asset_warn_notice.info_desc
                                    
                                asset_warn_notice.info_json = SevenHelper.json_dumps(asset_inventory)
                                asset_warn_notice.create_date = now_date
                                asset_warn_notice.create_day = now_day_int
                                asset_warn_notice_model.add_entity(asset_warn_notice)

                        except Exception as ex:
                            logger_error.error(f"资产每日进销存预警队列{mod_value}异常,json串:{SevenHelper.json_dumps(asset_inventory)},ex:{ex.decode()}")
                            continue
                else:
                    time.sleep(60 * 60)
            except Exception as ex:
                time.sleep(10)
          
    def _start_process_stat_queue(self, sub_table, mod_count):

        for i in range(mod_count):

            t = threading.Thread(target=self._process_stat_queue, args=[sub_table, i, mod_count])
            t.start()

    def _process_stat_queue(self, sub_table, mod_value, mod_count):
        """
        :description: 处理统计队列
        :param sub_table: 分表名称
        :param mod_value: 当前队列值
        :param mod_count: 队列数
        :return: 
        :last_editors: HuangJianYi
        """
        db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
        stat_queue_model = StatQueueModel(sub_table=sub_table, db_transaction=db_transaction)
        stat_log_model = StatLogModel(sub_table=sub_table, db_transaction=db_transaction)
        stat_report_model = StatReportModel(db_transaction=db_transaction)
        stat_orm_model = StatOrmModel()
        print(f"{TimeHelper.get_now_format_time()} 统计队列{mod_value}启动")
        while True:
            try:
                now_date = TimeHelper.get_now_format_time()
                now_day_int = SevenHelper.get_now_day_int()
                now_month_int = SevenHelper.get_now_month_int()
                stat_queue_list = stat_queue_model.get_list(f"MOD(user_id,{mod_count})={mod_value} and process_count<10 and '{now_date}'>process_date", order_by="process_date asc", limit="100")
                if len(stat_queue_list) > 0:
                    redis_init = SevenHelper.redis_init()
                    for stat_queue in stat_queue_list:
                        try:
                            redis_stat_orm_key = f"stat_orm_info:{stat_queue.act_id}_{stat_queue.module_id}_{stat_queue.key_name}"
                            stat_orm = redis_init.get(redis_stat_orm_key)
                            if not stat_orm:
                                stat_orm = stat_orm_model.get_entity("((act_id=%s and module_id=%s) or (act_id=0 and module_id=0)) and key_name=%s", params=[stat_queue.act_id, stat_queue.module_id, stat_queue.key_name])
                                if stat_orm:
                                    redis_init.set(redis_stat_orm_key, SevenHelper.json_dumps(stat_orm), ex=config.get_value("cache_expire", 60 * 1))
                            if not stat_orm:
                                stat_queue.process_count += 1
                                stat_queue.process_result = "orm不存在"
                                minute = 1 if stat_queue.process_count <= 5 else 5
                                stat_queue.process_date = TimeHelper.add_minutes_by_format_time(minute=minute)
                                stat_queue_model.update_entity(stat_queue, "process_count,process_result,process_date")
                                continue
                            if isinstance(stat_orm, StatOrm) == False:
                                stat_orm = json.loads(stat_orm)
                            is_add = True
                            if stat_orm.is_repeat == 1:
                                if stat_orm.repeat_type == 2:
                                    stat_log_total = stat_log_model.get_total("act_id=%s and module_id=%s and orm_id=%s and user_id=%s", params=[stat_orm.act_id, stat_orm.module_id, stat_orm.id, stat_orm.user_id])
                                else:
                                    stat_log_total = stat_log_model.get_total("act_id=%s and module_id=%s and orm_id=%s and user_id=%s and create_day=%s", params=[stat_orm.act_id, stat_orm.module_id, stat_orm.id, stat_orm.user_id, now_day_int])
                                if stat_log_total > 0:
                                    is_add = False

                            stat_log = StatLog()
                            stat_log.app_id = stat_queue.app_id
                            stat_log.act_id = stat_queue.act_id
                            stat_log.module_id = stat_queue.module_id
                            stat_log.orm_id = stat_queue.orm_id
                            stat_log.user_id = stat_queue.user_id
                            stat_log.open_id = stat_queue.open_id
                            stat_log.key_value = stat_queue.key_value
                            stat_log.create_day = now_day_int
                            stat_log.create_month = now_month_int
                            stat_log.create_date = now_date

                            stat_report_condition = "act_id=%s and module_id=%s and key_name=%s and create_day=%s"
                            stat_report_param = [stat_orm.act_id, stat_orm.module_id, stat_orm.key_name, now_day_int]
                            stat_report_total = stat_report_model.get_total(stat_report_condition, params=stat_report_param)

                            db_transaction.begin_transaction()
                            if is_add:
                                if stat_report_total == 0:
                                    stat_report = StatReport()
                                    stat_report.app_id = stat_queue.app_id
                                    stat_report.act_id = stat_queue.act_id
                                    stat_report.module_id = stat_queue.module_id
                                    stat_report.key_name = stat_queue.key_name
                                    stat_report.key_value = stat_queue.key_value
                                    stat_report.create_date = now_date
                                    stat_report.create_year = now_date.year
                                    stat_report.create_month = now_month_int
                                    stat_report.create_day = now_day_int
                                    stat_report_model.add_entity(stat_report)
                                else:
                                    stat_report_model.update_table(f"key_value=key_value+{stat_queue.key_value}", stat_report_condition, params=stat_report_param)
                            stat_log_model.add_entity(stat_log)
                            stat_queue_model.del_entity("id=%s", params=[stat_queue.id])
                            db_transaction.commit_transaction()

                        except Exception as ex:
                            logger_error.error(f"统计队列{mod_value}异常,json串:{SevenHelper.json_dumps(stat_queue)},ex:{ex.decode()}")
                            db_transaction.rollback_transaction()
                            stat_queue.process_count += 1
                            stat_queue.process_result = f"出现异常,json串:{SevenHelper.json_dumps(stat_queue)},ex:{ex.decode()}"
                            minute = 1 if stat_queue.process_count <= 5 else 5
                            stat_queue.process_date = TimeHelper.add_minutes_by_format_time(minute=minute)
                            stat_queue_model.update_entity(stat_queue, "process_count,process_result,process_date")
                            continue
                else:
                    time.sleep(1)
            except Exception as ex:
                time.sleep(10)
                
            



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2021-08-10 10:41:13
@LastEditTime: 2021-08-10 10:48:53
@LastEditors: HuangJianYi
@Description: 
"""
from seven_cloudapp_frame.models.seven_model import *
from seven_cloudapp_frame.libs.customize.seven_helper import *
from seven_cloudapp_frame.models.act_base_model import *
from seven_cloudapp_frame.models.db_models.task.task_info_model import *


# class TaskBaseModel():
#     """
#     :description: 任务基类
#     """
#     def __init__(self, context):
#         self.context = context

#     def get_task_list(self,app_id,act_id,module_id,prize_name,ascription_type,is_del,page_size,page_index,is_cache=True):
#         """
#         :description: 获取活动奖品列表
#         :param app_id: 应用标识
#         :param act_id: 活动标识
#         :param module_id: 活动模块标识
#         :param prize_name: 奖品名称
#         :param ascription_type: 奖品归属类型（0-活动奖品1-任务奖品）
#         :param is_del：是否回收站1是0否
#         :param page_size: 条数
#         :param page_index: 页数
#         :param is_cache: 是否缓存
#         :return: 
#         :last_editors: HuangJianYi
#         """
#         order_by = "sort_index desc,id asc"
#         condition = "app_id=%s and act_id=%s"
#         params = [app_id,act_id]
#         if ascription_type !=-1:
#             condition += " and ascription_type=%s"
#             params.append(is_del)
#         if is_del !=-1:
#             condition += " and is_del=%s"
#             params.append(is_del)
#         if module_id !=-1:
#             condition += " and module_id=%s"
#             params.append(module_id)
#         if prize_name:
#             condition += " and prize_name=%s"
#             params.append(prize_name)
#         act_prize_model = ActPrizeModel(context=self.context)
#         if is_cache:
#             page_list = act_prize_model(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by, params=params,dependency_key=f"act_prize_list:actid_{act_id}")
#         else:
#             page_list = act_prize_model.get_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by, params=params)    
#         return page_list, total


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-06-02 14:32:40
@LastEditTime: 2021-08-03 18:16:25
@LastEditors: HuangJianYi
:description: 枚举类
"""

from enum import Enum, unique

class OperationType(Enum):
    """
    :description: 用户操作日志类型
    """
    add = 1 #添加
    update = 2 #更新
    delete = 3 #删除
    review = 4 #还原






#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *


class ActPrizeModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(ActPrizeModel, self).__init__(ActPrize, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类

class ActPrize:

    def __init__(self):
        super(ActPrize, self).__init__()
        self.id = 0  # 标识
        self.app_id = ""  # 应用标识
        self.act_id = 0  # 活动标识
        self.module_id = 0  # 活动模块标识
        self.ascription_type = 0  # 奖品归属类型（0-活动奖品1-任务奖品）
        self.prize_name = ""  # 奖品名称
        self.prize_title = ""  # 奖品子标题
        self.prize_pic = ""  # 奖品图
        self.prize_detail_json = ""  # 奖品详情图（json）
        self.goods_id = 0  # 商品id
        self.goods_code = ""  # 商品编码
        self.goods_code_list = ""  # 多个sku商品编码
        self.goods_type = 0  # 物品类型（1虚拟2实物）
        self.prize_type = 0  # 奖品类型(1现货2优惠券3红包4参与奖5预售)
        self.prize_price = 0  # 奖品价格
        self.probability = 0  # 奖品权重
        self.chance = 0  # 概率
        self.prize_limit = 0  # 中奖限制
        self.is_prize_notice = 0  # 是否显示跑马灯(1是0否)
        self.surplus = 0  # 奖品库存
        self.is_surplus = 0  # 是否显示奖品库存（1显示0-不显示）
        self.prize_total = 0  # 奖品总数
        self.hand_out = 0  # 已发出数量
        self.lottery_type = 0  # 出奖类型（1概率出奖 2强制概率）
        self.tag_name = ""  # 标签名称(奖项名称)
        self.tag_id = 0  # 标签ID(奖项标识)
        self.sort_index = 0  # 排序
        self.is_del = 0  # 是否删除（1是0否）
        self.is_release = 0  # 是否发布（1是0否）
        self.is_sku = 0  # 是否有SKU
        self.sku_json = ""  # sku详情json
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.modify_date = "1900-01-01 00:00:00"  # 更新时间
        self.i1 = 0  # i1
        self.i2 = 0  # i2
        self.i3 = 0  # i3
        self.i4 = 0  # i4
        self.i5 = 0  # i5
        self.s1 = ""  # s1
        self.s2 = ""  # s2
        self.s3 = ""  # s3
        self.s4 = ""  # s4
        self.s5 = ""  # s5
        self.d1 = "1900-01-01 00:00:00"  # d1
        self.d2 = "1900-01-01 00:00:00"  # d2

    @classmethod
    def get_field_list(self):
        return ['id', 'app_id', 'act_id', 'module_id', 'ascription_type', 'prize_name', 'prize_title', 'prize_pic', 'prize_detail_json', 'goods_id', 'goods_code', 'goods_code_list', 'goods_type', 'prize_type', 'prize_price', 'probability', 'chance', 'prize_limit', 'is_prize_notice', 'surplus', 'is_surplus', 'prize_total', 'hand_out', 'lottery_type', 'tag_name', 'tag_id', 'sort_index', 'is_del', 'is_release', 'is_sku', 'sku_json', 'create_date', 'modify_date', 'i1', 'i2', 'i3', 'i4', 'i5', 's1','s2', 's3', 's4', 's5', 'd1', 'd2']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "act_prize_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2021-07-26 15:44:04
@LastEditTime: 2021-08-10 09:51:52
@LastEditors: HuangJianYi
@Description: 
"""
from seven_cloudapp_frame.models.seven_model import *
from seven_cloudapp_frame.libs.customize.seven_helper import *
from seven_cloudapp_frame.models.act_base_model import *
from seven_cloudapp_frame.models.db_models.theme.theme_info_model import *
from seven_cloudapp_frame.models.db_models.theme.theme_ver_model import *
from seven_cloudapp_frame.models.db_models.skin.skin_info_model import *
from seven_cloudapp_frame.models.db_models.act.act_info_model import *
from seven_cloudapp_frame.models.db_models.act.act_module_model import *

class ThemeBaseModel():
    """
    :description: 主题皮肤基类
    """
    def __init__(self, context):
        self.context = context

    def get_theme_info(self,theme_id, ver_no,is_cache=True):
        """
        :description: 获取主题信息
        :param act_id：活动标识
        :param theme_id：主题标识
        :param ver_no：客户端版本号
        :param is_cache：是否缓存
        :return: 返回主题信息
        :last_editors: HuangJianYi
        """
        theme_info_model = ThemeInfoModel(context=self.context)
        cache_key = f"theme_info:themeid_{theme_id}_verno_{ver_no}"
        redis_init = SevenHelper.redis_init()
        if is_cache:
             theme_info_dict = redis_init.get(cache_key)
             if theme_info_dict:
                    theme_info_dict = SevenHelper.json_loads(theme_info_dict)
                    return theme_info_dict
                    
        theme_info_dict = theme_info_model.get_dict_by_id(theme_id)
        if not theme_info_dict:
            return theme_info_dict
        out_id = theme_info_dict["out_id"]
        if ver_no:
            theme_ver = ThemeVerModel(context=self.context).get_dict("out_id=%s and ver_no=%s", params=[out_id, ver_no])
            if theme_ver and theme_ver["client_json"] != "":
                theme_info_dict["client_json"] = theme_ver["client_json"]
        skin_info_list = SkinInfoModel(context=self.context).get_dict_list("theme_id=%s", params=theme_id)
        theme_info_dict["skin_list"] = skin_info_list
        if is_cache:
            redis_init.set(cache_key, SevenHelper.json_dumps(theme_info_dict), ex=config.get_value("cache_expire", 600))
        return theme_info_dict
    
    def get_theme_list(self,app_id,is_cache=True):
        """
        :description: 获取主题列表
        :param app_id：应用标识
        :param is_cache：是否缓存
        :return: 获取主题列表
        :last_editors: HuangJianYi
        """
        where = "(app_id=%s or app_id='') and is_release=1"
        params = [app_id]
        theme_info_model = ThemeInfoModel(context=self.context)
        if is_cache:
            dict_list = theme_info_model.get_cache_dict_list(where=where, params=params)
        else:
            dict_list = theme_info_model.get_dict_list(where=where, params=params)
        
        for dict_info in dict_list:
            dict_info["server_json"] = SevenHelper.json_loads(dict_info["server_json"]) if dict_info["server_json"] else {}
        return dict_list
    
    def get_skin_list(self, theme_id=0, theme_out_id="",is_cache=True):
        """
        :description: 获取皮肤列表
        :param theme_id：主题标识
        :param theme_out_id：外部主题标识
        :param is_cache：是否缓存
        :return: 获取主题列表
        :last_editors: HuangJianYi
        """
        where = ""
        params = []
        if not theme_id or not theme_out_id:
            return []

        if theme_id:
            where = "theme_id=%s"
            params.append(theme_id)
        if theme_out_id:
            if where:
                where+=" and "
            where += " theme_out_id=%s"
            params.append(theme_out_id)
        if is_cache:
            dict_list = SkinInfoModel(context=self.context).get_cache_dict_list(where=where, params=params)
        else:
            dict_list = SkinInfoModel(context=self.context).get_dict_list(where=where, params=params)
        for dict_info in dict_list:
            dict_info["client_json"] = SevenHelper.json_loads(dict_info["client_json"]) if dict_info["client_json"] else {}
            dict_info["server_json"] = SevenHelper.json_loads(dict_info["server_json"]) if dict_info["server_json"] else {}
        return dict_list
    
    def update_act_theme_and_skin(self,app_id,act_id,theme_id,is_module):
        """
        :description: 更新活动主题和皮肤
        :param app_id：应用标识
        :param act_id：活动标识
        :param theme_id：主题标识
        :param is_module：是否更新活动模块皮肤
        :return: 获取主题列表
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        act_info_model = ActInfoModel(context=self.context)
        act_base_model = ActBaseModel(context=self.context)
        act_info_dict = act_base_model.get_act_info_dict(act_id,is_cache=False)
        if act_info_dict["app_id"] != app_id:
            invoke_result_data.success = False
            invoke_result_data.error_code = "error"
            invoke_result_data.error_message = "活动不存在"
            return invoke_result_data
        if act_info_dict["theme_id"] == theme_id:
            invoke_result_data.success = False
            invoke_result_data.error_code = "error"
            invoke_result_data.error_message = "主题未改变无需更改"
            return invoke_result_data

        skin_info = SkinInfoModel(context=self.context).get_entity("theme_id=%s", params=theme_id)
        if not skin_info:
            return self.response_json_error("error", "对不起，主题没有皮肤")
        act_info_model.update_table("theme_id=%s", "id=%s", [theme_id, act_id])
        if is_module == 1:
            ActModuleModel(context=self.context).update_table("skin_id=%s", "act_id=%s", [skin_info.id, act_id])
        return invoke_result_data
        

    def save_theme(self, app_id, theme_name, client_json, server_json, out_id, ver_no):
        """
        :description: 添加或修改主题
        :param app_id：app_id
        :param theme_name：主题名称
        :param client_json：客户端内容json
        :param server_json：服务端内容json
        :param out_id：外部id
        :param ver_no：客户端版本号
        :return: 
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        if not out_id:
            invoke_result_data.success = False
            invoke_result_data.error_code = "param_error"
            invoke_result_data.error_message = "参数不能为空或等于0"
            return invoke_result_data

        theme_info_model = ThemeInfoModel(context=self.context)
        theme_ver_model = ThemeVerModel(context=self.context)
        theme_info = theme_info_model.get_entity("out_id=%s", params=[out_id])
        if theme_info:
            if client_json:
                if ver_no:
                    theme_ver = theme_ver_model.get_entity('out_id=%s and ver_no=%s', params=[out_id, ver_no])
                    if theme_ver:
                        theme_ver_model.update_table('client_json=%s', 'out_id=%s and ver_no=%s', params=[client_json, out_id, ver_no])
                    else:
                        theme_ver = ThemeVer()
                        theme_ver.app_id = theme_info.app_id
                        theme_ver.out_id = out_id
                        theme_ver.theme_id = theme_info.id
                        theme_ver.client_json = client_json
                        theme_ver.ver_no = ver_no
                        theme_ver.create_date = theme_info.create_date
                        theme_ver_model.add_entity(theme_ver)
                else:
                    theme_info_model.update_table('client_json=%s', 'out_id=%s', params=[client_json, out_id])
            if server_json:
                theme_info_model.update_table('server_json=%s', 'out_id=%s', params=[server_json, out_id])
        else:
            theme_total = theme_info_model.get_total()
            if not theme_name:
                invoke_result_data.success = False
                invoke_result_data.error_code = "error"
                invoke_result_data.error_message = "主题名称不能为空"
                return invoke_result_data
            theme_info = ThemeInfo()
            theme_info.theme_name = theme_name
            theme_info.client_json = client_json
            theme_info.server_json = server_json
            theme_info.out_id = out_id
            if app_id != "":
                theme_info.app_id = app_id
                theme_info.is_private = 1
            theme_info.sort_index = int(theme_total) + 1
            theme_info.is_release = 1
            theme_info.create_date = self.get_now_datetime()
            theme_id = theme_info_model.add_entity(theme_info)
            if ver_no:
                theme_ver = ThemeVer()
                theme_ver.app_id = theme_info.app_id
                theme_ver.out_id = out_id
                theme_ver.theme_id = theme_id
                theme_ver.client_json = client_json
                theme_ver.ver_no = ver_no
                theme_ver.create_date = theme_info.create_date
                theme_ver_model.add_entity(theme_ver)

        return invoke_result_data

    def save_skin(self, app_id, skin_name, client_json, server_json, theme_out_id, skin_out_id):
        """
        :description: 保存皮肤
        :param app_id：应用标识
        :param skin_name：皮肤名称
        :param client_json：客户端内容json
        :param server_json：服务端内容json
        :param theme_out_id：样式外部id
        :param skin_out_id：皮肤外部id
        :return: 
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        if not skin_out_id:
            invoke_result_data.success = False
            invoke_result_data.error_code = "param_error"
            invoke_result_data.error_message = "参数不能为空或等于0"
            return invoke_result_data
        skin_info_model = SkinInfoModel(context=self.context)
        skin_info = skin_info_model.get_entity("out_id=%s", params=[skin_out_id])
        if skin_info:
            if client_json:
                skin_info_model.update_table('client_json=%s', 'out_id=%s', params=[client_json, skin_out_id])
            if server_json:
                skin_info_model.update_table('server_json=%s', 'out_id=%s', params=[server_json, skin_out_id])
        else:
            skin_info_total = skin_info_model.get_total('theme_out_id=%s', params=theme_out_id)
            if not skin_name:
                invoke_result_data.success = False
                invoke_result_data.error_code = "error"
                invoke_result_data.error_message = "皮肤名称不能为空"
                return invoke_result_data
            theme_info_model = ThemeInfoModel(context=self.context)
            theme_info = theme_info_model.get_entity("out_id=%s", params=theme_out_id)
            if not theme_info:
                invoke_result_data.success = False
                invoke_result_data.error_code = "error"
                invoke_result_data.error_message = "没有找到对应主题"
                return invoke_result_data
            skin_info = SkinInfo()
            skin_info.skin_name = skin_name
            skin_info.client_json = client_json
            skin_info.server_json = server_json
            if app_id != "":
                skin_info.app_id = app_id
            skin_info.sort_index = skin_info_total + 1
            skin_info.theme_id = theme_info.id
            skin_info.create_date = self.get_now_datetime()
            skin_info.modify_date = self.get_now_datetime()
            skin_info.out_id = skin_out_id
            skin_info.theme_out_id = theme_out_id
            skin_id = skin_info_model.add_entity(skin_info)
        invoke_result_data.data = skin_id
        return invoke_result_data


# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2021-08-10 10:05:38
@LastEditTime: 2021-08-10 10:36:42
@LastEditors: HuangJianYi
@Description: 
"""

from seven_cloudapp_frame.handlers.frame_base import *
from seven_cloudapp_frame.models.enum import *
from seven_cloudapp_frame.models.db_models.task.task_info_model import *

class TaskInfoListHandler(TaoBaseHandler):
    """
    :description: 获取任务列表
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 获取任务列表
        :param act_id：活动标识
        :param module_id：活动模块标识
        :return list
        :last_editors: HuangJianYi
        """
        act_id = int(self.get_param("act_id", 0))
        module_id = int(self.get_param("module_id", 0))
        is_release = int(self.get_param("is_release", -1))
        condition = "act_id=%s"
        params = [act_id]
        if module_id >0:
            condition+=" and module_id=%s"
            params.append(module_id)
        if is_release !=-1:
            condition += " and is_release=%s"
            params.append(is_release)

        task_info_list_dict = TaskInfoModel(context=self).get_dict_list(condition, params=params,order_by="sort_index asc")
        for task_info in task_info_list_dict:
            task_info["task_config"] = SevenHelper.json_loads(task_info["task_config"]) if task_info["task_config"] else {}
        return self.reponse_json_success(task_info_list_dict)

class SaveTaskInfoHandler(TaoBaseHandler):
    """
    :description 保存任务
    """
    @filter_check_params("task_list,act_id,app_id")
    def post_async(self):
        """
        :description: 保存任务列表
        :param act_id：活动标识
        :param module_id：活动模块标识
        :param task_list：任务列表
        :return reponse_json_success
        :last_editors: HuangJianYi
        """
        app_id = self.get_app_id()
        act_id = int(self.get_param("act_id", 0))
        module_id = int(self.get_param("module_id", 0))
        task_list = self.get_param("task_list")
        try:
            task_list = SevenHelper.json_loads(task_list)
        except Exception as ex:
            task_list = []

        task_info_model = TaskInfoModel(context=self)
        for item in task_list:
            if not item.__contains__("task_type"):
                continue
            complete_type = int(item["complete_type"]) if item.__contains__("complete_type") else 1
            sort_index = int(item["sort_index"]) if item.__contains__("sort_index") else 0
            is_release = int(item["is_release"]) if item.__contains__("is_release") else 0
            task_config = SevenHelper.json_dumps(item["task_config"]) if item.__contains__("task_config") else {}
            if "id" in item.keys():
                task_info = task_info_model.get_entity_by_id(int(item["id"]))
                if task_info:
                    old_task_info = deepcopy(task_info)
                    task_info.task_type = int(item["task_type"])
                    task_info.modify_date = SevenHelper.get_now_datetime()
                    task_info.complete_type = complete_type
                    task_info.sort_index = sort_index
                    task_info.is_release = is_release
                    task_info.task_config = task_config
                    task_info_model.update_entity(task_info, "modify_date,complete_type,sort_index,is_release,task_config")
                    self.create_operation_log(OperationType.update.value, task_info.__str__(), "SaveTaskInfoHandler", SevenHelper.json_dumps(old_task_info.__dict__), SevenHelper.json_dumps(task_info.__dict__))
            else:
                task_info = TaskInfo()
                task_info.app_id = app_id
                task_info.act_id = act_id
                task_info.module_id = module_id
                task_info.task_type = int(item["task_type"])
                task_info.complete_type = complete_type
                task_info.task_config = task_config
                task_info.sort_index = sort_index
                task_info.is_release = is_release
                task_info.create_date = SevenHelper.get_now_datetime()
                task_info.modify_date = SevenHelper.get_now_datetime()
                task_info_model.add_entity(task_info)

                self.create_operation_log(OperationType.add.value, task_info.__str__(), "SaveTaskInfoHandler", None, SevenHelper.json_dumps(task_info))

        return self.reponse_json_success()


# -*- coding: utf-8 -*-
"""
:Author: HuangJianYi
:Date: 2021-07-15 11:57:53
@LastEditTime: 2021-08-09 14:55:30
@LastEditors: HuangJianYi
:description: 
"""
__all__ = ["base_s", "app_s", "act_s", "report_s", "user_s", "launch_s", "theme_s", "ip_s", "price_s", "goods_s", "module_s","prize_s","order_s"]
